Documentation
¶
Overview ¶
Package persist saves run information between sessions of fitplot.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ConnectDatabase ¶
InitializeDatabase opens a database file and create the appropriate tables.
func CreateTempFile ¶
CreateTempFile takes an in-memory array of bytes and stores it in a temporary file location (which varies by operating system)
func DeleteTempFile ¶
DeleteTempFile deletes the temp file if it exists. Assumes file
func InsertNewRecord ¶
InsertNewRecord inserts a new record into the runfiles table containing a filename and a binary blob. It assumes the database has been initialized and the table built.
func MigrateDatabase ¶
MigrateDatabase updates the database schema to the latest version.
Types ¶
Click to show internal directories.
Click to hide internal directories.